==> python-upwork-oauth2-3.0.1.tar.gz: python-upwork-oauth2-3.0.1/README.md <==
Python bindings for Upwork API (OAuth2)
============

[![License](https://img.shields.io/github/license/upwork/python-upwork-oauth2)](http://www.apache.org/licenses/LICENSE-2.0.html)
[![PyPI Version](https://badge.fury.io/py/python-upwork.svg)](http://badge.fury.io/py/python-upwork)
[![GitHub release](https://img.shields.io/github/release/upwork/python-upwork.svg)](https://github.com/upwork/python-upwork/releases)
[![Build Status](https://travis-ci.org/upwork/python-upwork.svg)](https://travis-ci.org/upwork/python-upwork)

# Upwork API

This project provides a set of resources of Upwork API from http://developers.upwork.com
 based on OAuth 2.0.

# Features
These are the supported API resources:

* My Info
* Custom Payments
* Hiring
* Job and Freelancer Profile
* Search Jobs and Freelancers
* Organization
* Messages
* Time and Financial Reporting
* Metadata
* Snapshot
* Team
* Workd Diary
* Activities

# License

Copyright 2020 Upwork Corporation. All Rights Reserved.

python-upwork is licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

## SLA
The usage of this API is ruled by the Terms of Use at:

    https://developers.upwork.com/api-tos.html

# Requirements
To integrate this library you need to have:

* Python 3.8+
* requests_oauthlib >= 1.3.0

## Installation

    pip3 install python-upwork

All the dependencies will be automatically installed as well.

## Usage

1.
Follow instructions from the `Installation` section.

2.
Run `myapp.py` and follow the instructions, or open `myapp.py` and type the `consumer_key` and `consumer_secret` that you previously got from the API Center.
***That's all. Run your app as `python myapp.py` and have fun.***'

==> python-upwork-oauth2-3.0.2.tar.gz: python-upwork-oauth2-3.0.2/README.md <==
Python bindings for Upwork API (OAuth2)
============

[![License](https://img.shields.io/github/license/upwork/python-upwork-oauth2)](http://www.apache.org/licenses/LICENSE-2.0.html)
[![PyPI Version](https://badge.fury.io/py/python-upwork.svg)](http://badge.fury.io/py/python-upwork)
[![GitHub release](https://img.shields.io/github/release/upwork/python-upwork.svg)](https://github.com/upwork/python-upwork/releases)
[![Build Status](https://travis-ci.org/upwork/python-upwork.svg)](https://travis-ci.org/upwork/python-upwork)

# Upwork API

This project provides a set of resources of Upwork API from http://developers.upwork.com
 based on OAuth 2.0.

# Features
These are the supported API resources:

* My Info
* Custom Payments
* Hiring
* Job and Freelancer Profile
* Search Jobs and Freelancers
* Organization
* Messages
* Time and Financial Reporting
* Metadata
* Snapshot
* Team
* Workd Diary
* Activities

# License

Copyright 2020 Upwork Corporation. All Rights Reserved.

python-upwork is licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

## SLA
The usage of this API is ruled by the Terms of Use at:

    https://developers.upwork.com/api-tos.html

# Requirements
To integrate this library you need to have:

* Python 3.8+
* requests_oauthlib >= 1.3.0

## Installation

    pip3 install python-upwork-oauth2

All the dependencies will be automatically installed as well.

## Usage

1.
Follow instructions from the `Installation` section.

2.
Run `myapp.py` and follow the instructions, or open `myapp.py` and type the `consumer_key` and `consumer_secret` that you previously got from the API Center.
***That's all. Run your app as `python myapp.py` and have fun.***'
